@@ -101,7 +101,7 @@ class MoleculeEnv(object):
                                 if d.is_dir()])
             else:
                 # roles dir viewed from a role molecule scenario
-                roles_dir = roles_dir / '../../roles'
+                roles_dir = msd / '../../../../roles'
                 if roles_dir.is_dir():
                     roles = sorted([d.name for d in roles_dir.iterdir()
                                     if d.is_dir()])
